==> gcc-4.1.2.tar.bz2: gcc-4.1.2/libjava/classpath/javax/naming/spi/ObjectFactoryBuilder.java <==
/* ObjectFactoryBuilder.java --
   Copyright (C) 2001, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.naming.spi;

import java.util.Hashtable;

import javax.naming.NamingException;
 
/**
 * @author Warren Levy (warrenl@redhat.com)
 * @date June 1, 2001
 */
public interface ObjectFactoryBuilder
{
  ObjectFactory createObjectFactory(Object obj,
  					   Hashtable environment)
					   throws NamingException;
}

==> gcc-4.2.3.tar.bz2: gcc-4.2.3/libjava/classpath/javax/naming/spi/ObjectFactoryBuilder.java <==
/* ObjectFactoryBuilder.java -- the builder that creates the object factories.
   Copyright (C) 2001, 2004, 2006  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.naming.spi;

import java.util.Hashtable;

import javax.naming.NamingException;
import javax.naming.Reference;
import javax.naming.Referenceable;
 
/**
 * Represents the builder that creates the object factories.
 * 
 * @see NamingManager#setObjectFactoryBuilder(ObjectFactoryBuilder)
 * 
 * @author Warren Levy (warrenl@redhat.com)
 */
public interface ObjectFactoryBuilder
{ 
  /**
   * Create a new object using the supplied environment.
   * 
   * @param refInfo the referencing object, for which the new object must be
   *          created (can be null). If not null, it is usually an instance of
   *          the {@link Reference} or {@link Referenceable}.
   * @param environment contains the additional information about the factory
   *          being created. Can be null.
   * @return the created object factory. The null is never returned.
   * @throws NamingException
   */
  ObjectFactory createObjectFactory(Object refInfo,
  					   Hashtable environment)
					   throws NamingException;
}
